# BGT Client
A simple command line client for the bgt transaction family.
## Usage
Simply type "bgtc" followed bo your command, followed by your parameters. 
1. version 
2. connect IP:PORT
3. output FILENAME
4. set WALLETNAME [Tokens] [Wait]
5. inc WALLETNAME [Tokens] [Wait]
6. dec WALLETNAME [Tokens] [Wait]
7. trans WALLET1 WALLET2 [Tokens] [Wait]
8. show WALLET [Wait]
9. execute FILEPATH
10. exit
11. list [Wait]
12. output FILENAME  
